@@ -15,6 +15,7 @@
 #include "netlink-message.h"
 #include "netlink.h"
 #include "network-address.h"
+#include "netlink-missing.h"
 #include "network-util.h"
 #include "set.h"
 
@@ -32,7 +33,7 @@ static int addresses_new(Addresses **ret) {
         if (r < 0)
                 return r;
 
-        *ret = steal_pointer(h);
+        *ret = steal_ptr(h);
         return 0;
 }
 
@@ -114,7 +115,7 @@ static int validate_address_attributes(const struct nlattr *attr, void *data) {
 
 static int fill_link_address(const struct nlmsghdr *nlh, void *data) {
         struct ifaddrmsg *ifa = mnl_nlmsg_get_payload(nlh);
-        struct nlattr *tb[IFA_MAX + 1] = {};
+        struct nlattr *tb[IFA_MAX + 2] = {};
         _auto_cleanup_ Address *a = NULL;
         Addresses *addrs = data;
         int r;
@@ -128,6 +129,7 @@ static int fill_link_address(const struct nlmsghdr *nlh, void *data) {
 
         *a = (Address) {
            .family = ifa->ifa_family,
+           .flags = ifa->ifa_flags,
            .ifindex = ifa->ifa_index,
            .scope = ifa->ifa_scope,
            .address.prefix_len = ifa->ifa_prefixlen,
@@ -151,11 +153,33 @@ static int fill_link_address(const struct nlmsghdr *nlh, void *data) {
                         memcpy(&a->address.in6, mnl_attr_get_payload(tb[IFA_ADDRESS]), sizeof(struct in6_addr));
         }
 
+        if (tb[IFA_BROADCAST]) {
+                if (a->family == AF_INET)
+                        memcpy(&a->broadcast.in, mnl_attr_get_payload(tb[IFA_BROADCAST]), sizeof(struct in_addr));
+                else
+                        memcpy(&a->broadcast.in6, mnl_attr_get_payload(tb[IFA_BROADCAST]), sizeof(struct in6_addr));
+        }
+
+        if (tb[IFA_FLAGS])
+                a->flags = mnl_attr_get_u32(tb[IFA_FLAGS]);
+
+        if (tb[IFA_PROTO])
+                a->proto = mnl_attr_get_u8(tb[IFA_PROTO]);
+
+        if (tb[IFA_LABEL]) {
+                a->label = strdup(mnl_attr_get_str(tb[IFA_LABEL]));
+                if (!a->label)
+                        return -ENOMEM;
+        }
+
+        if (tb[IFA_CACHEINFO])
+                memcpy(&a->ci, mnl_attr_get_payload(tb[IFA_CACHEINFO]), sizeof(struct ifa_cacheinfo));
+
         r = address_add(&addrs, a);
         if (r < 0)
                 return r;
 
-        steal_pointer(a);
+        steal_ptr(a);
         return MNL_CB_OK;
 }
 
@@ -189,7 +213,7 @@ static int acquire_link_address(int s, int ifindex, Addresses **ret) {
         return 0;
 }
 
-int manager_link_get_address(Addresses **ret) {
+int netlink_acquire_all_link_addresses(Addresses **ret) {
        _auto_cleanup_close_ int s = -1;
         int r;
 
@@ -202,7 +226,7 @@ int manager_link_get_address(Addresses **ret) {
         return acquire_link_address(s, 0, ret);
 }
 
-int manager_get_one_link_address(int ifindex, Addresses **ret) {
+int netlink_get_one_link_address(int ifindex, Addresses **ret) {
         _auto_cleanup_close_ int s = -1;
         int r;
 
@@ -229,6 +253,8 @@ static int link_add_address(int s, int ifindex, IPAddress *address, IPAddress *p
                 return r;
 
         m->ifm.ifa_prefixlen = address->prefix_len;
+        m->ifm.ifa_flags = address->flags;
+        m->ifm.ifa_scope = address->scope;
 
         if (address->family == AF_INET)
                 r = rtnl_message_add_attribute(&m->hdr, IFA_LOCAL, &address->in, sizeof(struct in_addr));
@@ -249,7 +275,7 @@ static int link_add_address(int s, int ifindex, IPAddress *address, IPAddress *p
         return netlink_call(s, &m->hdr, m->buf, sizeof(m->buf));
 }
 
-int manager_link_add_address(int ifindex, IPAddress *address, IPAddress *peer) {
+int netlink_add_link_address(int ifindex, IPAddress *address, IPAddress *peer) {
        _auto_cleanup_close_ int s = -1;
        int r;
 
